#[repr(C)]pub struct DeviceEnableRequest {
pub enable: bool,
}Fields
enable: boolTrait Implementations
Sourceimpl Clone for DeviceEnableRequest
impl Clone for DeviceEnableRequest
Sourcefn clone(&self) -> DeviceEnableRequest
fn clone(&self) -> DeviceEnableRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceEnableRequest
Sourceimpl Debug for DeviceEnableRequest
impl Debug for DeviceEnableRequest
Sourceimpl<___E> Encode<DeviceEnableRequest, ___E> for DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceEnableRequest, ___E> for DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceEnableRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceEnableRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceEnableRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceEnableRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceEnableRequest, ___E> for &'a DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceEnableRequest, ___E> for &'a DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceEnableRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceEnableRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceEnableRequest>, ___E> for DeviceEnableRequest
impl<___E> EncodeOption<Box<'static, DeviceEnableRequest>, ___E> for DeviceEnableRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceEnableRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceEnableRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceEnableRequest>, ___E> for &'a DeviceEnableRequest
impl<'a, ___E> EncodeOption<Box<'static, DeviceEnableRequest>, ___E> for &'a DeviceEnableRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceEnableRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceEnableRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for DeviceEnableRequest
Sourceimpl FromWire<DeviceEnableRequest> for DeviceEnableRequest
impl FromWire<DeviceEnableRequest> for DeviceEnableRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceEnableRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceEnableRequest, Self>
Sourcefn from_wire(wire: DeviceEnableRequest) -> Self
fn from_wire(wire: DeviceEnableRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceEnableRequest> for DeviceEnableRequest
impl FromWireRef<DeviceEnableRequest> for DeviceEnableRequest
Sourcefn from_wire_ref(wire: &DeviceEnableRequest) -> Self
fn from_wire_ref(wire: &DeviceEnableRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceEnableRequest
impl Hash for DeviceEnableRequest
Sourceimpl Ord for DeviceEnableRequest
impl Ord for DeviceEnableRequest
Sourcefn cmp(&self, other: &DeviceEnableRequest) -> Ordering
fn cmp(&self, other: &DeviceEnableRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DeviceEnableRequest
impl PartialEq for DeviceEnableRequest
Sourceimpl PartialOrd for DeviceEnableRequest
impl PartialOrd for DeviceEnableRequest
impl StructuralPartialEq for DeviceEnableRequest