pub struct DeviceGetInfoResponse {
pub info: SerialPortInfo,
}Fields
info: SerialPortInfoTrait Implementations
Sourceimpl Clone for DeviceGetInfoResponse
impl Clone for DeviceGetInfoResponse
Sourcefn clone(&self) -> DeviceGetInfoResponse
fn clone(&self) -> DeviceGetInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetInfoResponse
impl Debug for DeviceGetInfoResponse
Sourceimpl<___E> Encode<DeviceGetInfoResponse, ___E> for DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetInfoResponse, ___E> for DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<DeviceGetInfoResponse, ___E> for &'a DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetInfoResponse, ___E> for &'a DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetInfoResponse>, ___E> for DeviceGetInfoResponse
impl<___E> EncodeOption<Box<'static, DeviceGetInfoResponse>, ___E> for DeviceGetInfoResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetInfoResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetInfoResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetInfoResponse>, ___E> for &'a DeviceGetInfoResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetInfoResponse>, ___E> for &'a DeviceGetInfoResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetInfoResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetInfoResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetInfoResponse> for DeviceGetInfoResponse
impl FromWire<DeviceGetInfoResponse> for DeviceGetInfoResponse
Sourcefn from_wire(wire: DeviceGetInfoResponse) -> Self
fn from_wire(wire: DeviceGetInfoResponse) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<DeviceGetInfoResponse> for DeviceGetInfoResponse
impl FromWireRef<DeviceGetInfoResponse> for DeviceGetInfoResponse
Sourcefn from_wire_ref(wire: &DeviceGetInfoResponse) -> Self
fn from_wire_ref(wire: &DeviceGetInfoResponse) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for DeviceGetInfoResponse
impl PartialEq for DeviceGetInfoResponse
impl StructuralPartialEq for DeviceGetInfoResponse