pub struct DeviceReadResponse {
pub data: Vec<u8>,
}Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceReadResponse
impl Clone for DeviceReadResponse
Sourcefn clone(&self) -> DeviceReadResponse
fn clone(&self) -> DeviceReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceReadResponse
impl Debug for DeviceReadResponse
Sourceimpl<___E> Encode<DeviceReadResponse<'static>, ___E> for DeviceReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceReadResponse<'static>, ___E> for DeviceReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<DeviceReadResponse<'static>, ___E> for &'a DeviceReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceReadResponse<'static>, ___E> for &'a DeviceReadResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceReadResponse<'static>>, ___E> for DeviceReadResponse
impl<___E> EncodeOption<Box<'static, DeviceReadResponse<'static>>, ___E> for DeviceReadResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceReadResponse<'static>>, ___E> for &'a DeviceReadResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceReadResponse<'static>>, ___E> for &'a DeviceReadResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for DeviceReadResponse
Sourceimpl<'de> FromWire<DeviceReadResponse<'de>> for DeviceReadResponse
impl<'de> FromWire<DeviceReadResponse<'de>> for DeviceReadResponse
Sourcefn from_wire(wire: DeviceReadResponse<'de>) -> Self
fn from_wire(wire: DeviceReadResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceReadResponse<'de>> for DeviceReadResponse
impl<'de> FromWireRef<DeviceReadResponse<'de>> for DeviceReadResponse
Sourcefn from_wire_ref(wire: &DeviceReadResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceReadResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceReadResponse
impl Hash for DeviceReadResponse
Sourceimpl Ord for DeviceReadResponse
impl Ord for DeviceReadResponse
Sourcefn cmp(&self, other: &DeviceReadResponse) -> Ordering
fn cmp(&self, other: &DeviceReadResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DeviceReadResponse
impl PartialEq for DeviceReadResponse
Sourceimpl PartialOrd for DeviceReadResponse
impl PartialOrd for DeviceReadResponse
impl StructuralPartialEq for DeviceReadResponse