#[repr(C)]pub struct DeviceConfigRequest {
pub baud_rate: Uint32,
pub flags: Uint32,
}Expand description
The wire type corresponding to DeviceConfigRequest.
Fields
baud_rate: Uint32flags: Uint32Trait Implementations
Sourceimpl Clone for DeviceConfigRequest
impl Clone for DeviceConfigRequest
Sourcefn clone(&self) -> DeviceConfigRequest
fn clone(&self) -> DeviceConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceConfigRequest
impl Constrained for DeviceConfigRequest
Sourceimpl Debug for DeviceConfigRequest
impl Debug for DeviceConfigRequest
Sourceimpl<___D> Decode<___D> for DeviceConfigRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceConfigRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<DeviceConfigRequest, ___E> for DeviceConfigRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceConfigRequest, ___E> for DeviceConfigRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceConfigRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceConfigRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceConfigRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceConfigRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceConfigRequest, ___E> for &'a DeviceConfigRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceConfigRequest, ___E> for &'a DeviceConfigRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceConfigRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceConfigRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<DeviceConfigRequest, ___E> for DeviceConfigRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<DeviceConfigRequest, ___E> for DeviceConfigRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceConfigRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceConfigRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceConfigRequest> for DeviceConfigRequest
impl FromWire<DeviceConfigRequest> for DeviceConfigRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceConfigRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceConfigRequest, Self>
Sourcefn from_wire(wire: DeviceConfigRequest) -> Self
fn from_wire(wire: DeviceConfigRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceConfigRequest> for DeviceConfigRequest
impl FromWireRef<DeviceConfigRequest> for DeviceConfigRequest
Sourcefn from_wire_ref(wire: &DeviceConfigRequest) -> Self
fn from_wire_ref(wire: &DeviceConfigRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceConfigRequest
impl IntoNatural for DeviceConfigRequest
Sourcetype Natural = DeviceConfigRequest
type Natural = DeviceConfigRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceConfigRequest
impl Wire for DeviceConfigRequest
Sourcetype Narrowed<'de> = DeviceConfigRequest
type Narrowed<'de> = DeviceConfigRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.