#[repr(C)]pub struct DeviceEnableRequest {
pub enable: bool,
}Expand description
The wire type corresponding to DeviceEnableRequest.
Fields
enable: boolTrait Implementations
Sourceimpl Clone for DeviceEnableRequest
impl Clone for DeviceEnableRequest
Sourcefn clone(&self) -> DeviceEnableRequest
fn clone(&self) -> DeviceEnableRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceEnableRequest
impl Constrained for DeviceEnableRequest
Sourceimpl Debug for DeviceEnableRequest
impl Debug for DeviceEnableRequest
Sourceimpl<___D> Decode<___D> for DeviceEnableRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceEnableRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<DeviceEnableRequest, ___E> for DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceEnableRequest, ___E> for DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceEnableRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceEnableRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceEnableRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceEnableRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DeviceEnableRequest, ___E> for &'a DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceEnableRequest, ___E> for &'a DeviceEnableRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceEnableRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceEnableRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<DeviceEnableRequest, ___E> for DeviceEnableRequest<T0>
impl<___E, T0> Encode<DeviceEnableRequest, ___E> for DeviceEnableRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceEnableRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceEnableRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceEnableRequest> for DeviceEnableRequest
impl FromWire<DeviceEnableRequest> for DeviceEnableRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceEnableRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceEnableRequest, Self>
Sourcefn from_wire(wire: DeviceEnableRequest) -> Self
fn from_wire(wire: DeviceEnableRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceEnableRequest> for DeviceEnableRequest
impl FromWireRef<DeviceEnableRequest> for DeviceEnableRequest
Sourcefn from_wire_ref(wire: &DeviceEnableRequest) -> Self
fn from_wire_ref(wire: &DeviceEnableRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceEnableRequest
impl IntoNatural for DeviceEnableRequest
Sourcetype Natural = DeviceEnableRequest
type Natural = DeviceEnableRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceEnableRequest
impl Wire for DeviceEnableRequest
Sourcetype Narrowed<'de> = DeviceEnableRequest
type Narrowed<'de> = DeviceEnableRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.