#[repr(C)]pub struct DeviceGetInfoResponse {
pub info: SerialPortInfo,
}Expand description
The wire type corresponding to DeviceGetInfoResponse.
Fields
info: SerialPortInfoTrait Implementations
Sourceimpl Clone for DeviceGetInfoResponse
impl Clone for DeviceGetInfoResponse
Sourcefn clone(&self) -> DeviceGetInfoResponse
fn clone(&self) -> DeviceGetInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetInfoResponse
impl Constrained for DeviceGetInfoResponse
Sourceimpl Debug for DeviceGetInfoResponse
impl Debug for DeviceGetInfoResponse
Sourceimpl<___D> Decode<___D> for DeviceGetInfoResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetInfoResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<DeviceGetInfoResponse, ___E> for DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetInfoResponse, ___E> for DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<DeviceGetInfoResponse, ___E> for &'a DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetInfoResponse, ___E> for &'a DeviceGetInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<DeviceGetInfoResponse, ___E> for DeviceGetInfoResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<SerialPortInfo, ___E>,
impl<___E, T0> Encode<DeviceGetInfoResponse, ___E> for DeviceGetInfoResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<SerialPortInfo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetInfoResponse> for DeviceGetInfoResponse
impl FromWire<DeviceGetInfoResponse> for DeviceGetInfoResponse
Sourcefn from_wire(wire: DeviceGetInfoResponse) -> Self
fn from_wire(wire: DeviceGetInfoResponse) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<DeviceGetInfoResponse> for DeviceGetInfoResponse
impl FromWireRef<DeviceGetInfoResponse> for DeviceGetInfoResponse
Sourcefn from_wire_ref(wire: &DeviceGetInfoResponse) -> Self
fn from_wire_ref(wire: &DeviceGetInfoResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetInfoResponse
impl IntoNatural for DeviceGetInfoResponse
Sourcetype Natural = DeviceGetInfoResponse
type Natural = DeviceGetInfoResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetInfoResponse
impl Wire for DeviceGetInfoResponse
Sourcetype Narrowed<'de> = DeviceGetInfoResponse
type Narrowed<'de> = DeviceGetInfoResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.